braindecode.datautil.preprocess
===============================

.. currentmodule:: braindecode.datautil

.. autofunction:: preprocess

.. include:: braindecode.datautil.preprocess.examples

.. raw:: html

    <div style='clear:both'></div>